@@ -38,12 +38,13 @@ extern "C"
 
 #include "plugins/audiocdencoder.h"
 
-#include <sys/stat.h>
 #include <unistd.h>
-#include <stdlib.h>
-#include <sys/time.h>
+#include <sys/stat.h>
 #include <sys/resource.h>
 
+#include <cstdlib>
+#include <ctime>
+
 #include <QApplication>
 #include <QFile>
 #include <QFileInfo>
@@ -59,7 +60,7 @@ extern "C"
 
 // CDDB
 #include <KCddb/Client>
-#include <KCompactDisc/KCompactDisc>
+#include <KCompactDisc>
 
 // Pseudo plugin class to embed metadata
 class KIOPluginForMetaData : public QObject
